pub struct WorkerConfig {
pub ack_on_decode_error: bool,
}Fields
ack_on_decode_error: bool- If true, the worker will ack a message if it fails to decode the task, use this option if you are sure that its a publisher error.
- If false, the worker will nack a message if it fails to decode the task, use this option if you might be attaching the worker to the wrong queue or your decoding logic is faulty.